==> libro-codemirror-0.1.7.tgz: package/es/monitor.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { EditorView, hasHoverTooltips } from '@codemirror/view';
import { Emitter } from '@difizen/mana-app';
import { closeCompletionEffect, setSelectedEffect, startCompletionEffect } from "./auto-complete/state.js";
export var CompletionMonitor = /*#__PURE__*/function () {
  function CompletionMonitor() {
    _classCallCheck(this, CompletionMonitor);
    this.completionChangeEmitter = new Emitter();
    this.tooltipChangeEmitter = new Emitter();
  }
  _createClass(CompletionMonitor, [{
    key: "compeltionChange",
    get: function get() {
      return this.completionChangeEmitter.event;
    }
  }, {
    key: "onTooltipChange",
    get: function get() {
      return this.tooltipChangeEmitter.event;
    }
  }, {
    key: "start",
    value: function start(doc) {
      this.currentChange = {
        start: doc,
        selectIndex: 0
      };
    }
  }, {
    key: "accept",
    value: function accept(doc) {
      this.currentChange = _objectSpread(_objectSpread({}, this.currentChange), {
        accept: doc
      });
      this.emitChange(this.currentChange);
    }
  }, {
    key: "close",
    value: function close(doc) {
      this.currentChange = _objectSpread(_objectSpread({}, this.currentChange), {
        close: doc,
        selectIndex: -1
      });
      this.emitChange(this.currentChange);
    }
  }, {
    key: "updateIndex",
    value: function updateIndex(index) {
      this.currentChange = _objectSpread(_objectSpread({}, this.currentChange), {
        selectIndex: index
      });
    }
  }, {
    key: "emitChange",
    value: function emitChange(change) {
      this.completionChangeEmitter.fire(change);
    }
  }], [{
    key: "getInstance",
    value: function getInstance() {
      if (!CompletionMonitor.instance) {
        CompletionMonitor.instance = new CompletionMonitor();
      }
      return CompletionMonitor.instance;
    }
  }]);
  return CompletionMonitor;
}();
export var monitorPlugin = function monitorPlugin(options) {
  return EditorView.updateListener.of(function (update) {
    var _iterator = _createForOfIteratorHelper(update.transactions),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _options$onTooltipCha;
        var trans = _step.value;
        var effects = trans.effects;
        options === null || options === void 0 || (_options$onTooltipCha = options.onTooltipChange) === null || _options$onTooltipCha === void 0 || _options$onTooltipCha.call(options, hasHoverTooltips(update.state));
        if (trans.isUserEvent('input.complete')) {
          CompletionMonitor.getInstance().accept({
            changes: JSON.stringify(trans.changes.toJSON()),
            cursor: update.state.selection.main.head,
            source: update.state.doc.toJSON()
          });
        }
        var _iterator2 = _createForOfIteratorHelper(effects),
          _step2;
        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var effect = _step2.value;
            if (effect.is(startCompletionEffect)) {
              CompletionMonitor.getInstance().start({
                cursor: update.state.selection.main.head,
                source: update.state.doc.toJSON()
              });
            } else if (effect.is(closeCompletionEffect)) {
              CompletionMonitor.getInstance().close({
                cursor: update.state.selection.main.head,
                source: update.state.doc.toJSON()
              });
            } else if (effect.is(setSelectedEffect)) {
              CompletionMonitor.getInstance().updateIndex(effect.value);
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return null;
  });
};

==> libro-codemirror-0.1.13.tgz: package/es/monitor.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _createForOfIteratorHelper(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (!it) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = it.call(o); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it.return != null) it.return(); } finally { if (didErr) throw err; } } }; }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import { EditorView, hasHoverTooltips } from '@codemirror/view';
import { Emitter } from '@difizen/mana-app';
import { closeCompletionEffect, setSelectedEffect, startCompletionEffect } from "./auto-complete/state.js";
export var CompletionMonitor = /*#__PURE__*/function () {
  function CompletionMonitor() {
    _classCallCheck(this, CompletionMonitor);
    this.completionChangeEmitter = new Emitter();
    this.tooltipChangeEmitter = new Emitter();
  }
  _createClass(CompletionMonitor, [{
    key: "compeltionChange",
    get: function get() {
      return this.completionChangeEmitter.event;
    }
  }, {
    key: "onTooltipChange",
    get: function get() {
      return this.tooltipChangeEmitter.event;
    }
  }, {
    key: "start",
    value: function start(doc) {
      this.currentChange = {
        start: doc,
        selectIndex: 0
      };
    }
  }, {
    key: "accept",
    value: function accept(doc) {
      this.currentChange = _objectSpread(_objectSpread({}, this.currentChange), {
        accept: doc
      });
      this.emitChange(this.currentChange);
    }
  }, {
    key: "close",
    value: function close(doc) {
      this.currentChange = _objectSpread(_objectSpread({}, this.currentChange), {
        close: doc,
        selectIndex: -1
      });
      this.emitChange(this.currentChange);
    }
  }, {
    key: "updateIndex",
    value: function updateIndex(index) {
      this.currentChange = _objectSpread(_objectSpread({}, this.currentChange), {
        selectIndex: index
      });
    }
  }, {
    key: "emitChange",
    value: function emitChange(change) {
      this.completionChangeEmitter.fire(change);
    }
  }], [{
    key: "getInstance",
    value: function getInstance() {
      if (!CompletionMonitor.instance) {
        CompletionMonitor.instance = new CompletionMonitor();
      }
      return CompletionMonitor.instance;
    }
  }]);
  return CompletionMonitor;
}();
export var monitorPlugin = function monitorPlugin(options) {
  return EditorView.updateListener.of(function (update) {
    var _iterator = _createForOfIteratorHelper(update.transactions),
      _step;
    try {
      for (_iterator.s(); !(_step = _iterator.n()).done;) {
        var _options$onTooltipCha;
        var trans = _step.value;
        var effects = trans.effects;
        options === null || options === void 0 || (_options$onTooltipCha = options.onTooltipChange) === null || _options$onTooltipCha === void 0 || _options$onTooltipCha.call(options, hasHoverTooltips(update.state));
        if (trans.isUserEvent('input.complete')) {
          CompletionMonitor.getInstance().accept({
            changes: JSON.stringify(trans.changes.toJSON()),
            cursor: update.state.selection.main.head,
            source: update.state.doc.toJSON()
          });
        }
        var _iterator2 = _createForOfIteratorHelper(effects),
          _step2;
        try {
          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
            var effect = _step2.value;
            if (effect.is(startCompletionEffect)) {
              CompletionMonitor.getInstance().start({
                cursor: update.state.selection.main.head,
                source: update.state.doc.toJSON()
              });
            } else if (effect.is(closeCompletionEffect)) {
              CompletionMonitor.getInstance().close({
                cursor: update.state.selection.main.head,
                source: update.state.doc.toJSON()
              });
            } else if (effect.is(setSelectedEffect)) {
              CompletionMonitor.getInstance().updateIndex(effect.value);
            }
          }
        } catch (err) {
          _iterator2.e(err);
        } finally {
          _iterator2.f();
        }
      }
    } catch (err) {
      _iterator.e(err);
    } finally {
      _iterator.f();
    }
    return null;
  });
};
